<?php
/**
 * Template Name: College Evaluation Page
 *
 * Description: This is a custom template for displaying College Evaluation page.
 */
get_header();

global $wpdb;

$featured_image_url = esc_url(wp_upload_dir()['baseurl'].'/2025/05/casc.jpg');
if (has_post_thumbnail()) {
    $featured_image_id = get_post_thumbnail_id();
    $featured_image_url = wp_get_attachment_url($featured_image_id);
}

if (!session_id()) {
    session_start();
}

if(isset($_POST['login'])){
    $username = isset($_POST['username']) ? sanitize_text_field($_POST['username']) : null;
    $password = isset($_POST['password']) ? sanitize_text_field($_POST['password']) : null;
    
    $logdata = $wpdb->get_row($wpdb->prepare("SELECT * FROM logins WHERE id = 3 and username = %s and password = %s", $username, $password));
    if (!empty($logdata)) {
        $_SESSION['authenticated3'] = true;
    } else {
        echo '<script>
            alert(\'Invalid Username or Password.\');
        </script>';
    }
}

$departments = $wpdb->get_results($wpdb->prepare("SELECT * FROM departments WHERE deleted_at IS NULL ORDER BY name"));
$questions = $wpdb->get_results($wpdb->prepare("SELECT * FROM feedback WHERE type='1' and parent_id='0' AND deleted_at IS NULL ORDER BY priority ASC, id ASC"));
$questionall = $wpdb->get_results($wpdb->prepare("SELECT * FROM feedback WHERE type='1' AND deleted_at IS NULL ORDER BY priority ASC, id ASC"));

if(isset($_POST['btn_submit'])){
    $data = [];
    $data['student'] = isset($_POST['student']) ? sanitize_text_field($_POST['student']) : null;
    $data['department_id'] = isset($_POST['department']) ? intval($_POST['department']) : 0;
    
    $allowed_ctype_values = ['UG Course', 'PG Course'];
    $data['ctype'] = isset($_POST['ctype']) ? sanitize_text_field($_POST['ctype']) : null;
    if (!in_array($data['ctype'], $allowed_ctype_values)) {
        $data['ctype'] = null;
    }
    
    $data['course_id'] = isset($_POST['course']) ? intval($_POST['course']) : 0;
    
    $allowed_semester_values = ['Semester 1', 'Semester 2', 'Semester 3', 'Semester 4', 'Semester 5', 'Semester 6'];
    $data['semester'] = isset($_POST['semester']) ? sanitize_text_field($_POST['semester']) : null;
    if (!in_array($data['semester'], $allowed_semester_values)) {    
        $data['semester'] = null;
    }
    
    $data['year'] = isset($_POST['year']) ? intval($_POST['year']) : 0;
    $data['parent'] = isset($_POST['parent']) ? sanitize_text_field($_POST['parent']) : 0;
    $data['comments'] = isset($_POST['comments']) ? sanitize_textarea_field($_POST['comments']) : null;
    $data['created_at'] = date('Y-m-d H:i:s');
    
    if($data['student'] != null && $data['department_id'] > 0 && $data['ctype'] != null && $data['course_id'] > 0 && $data['semester'] != null && $data['year'] > 0 && $data['parent'] > 0){
        $format = array('%s', '%d', '%s', '%d', '%s', '%d', '%s', '%s','%s');
        $inserted = $wpdb->insert('parent_feedback', $data, $format);
        if($inserted){
            $parent_feedback_id = $wpdb->insert_id;
            
            $sdata = [];
            $sdata['parent_feedback_id'] = $parent_feedback_id;
           
            $sformat = array('%d', '%d', '%d', '%s');
            
            foreach($questionall as $question){
                $feedback_id = $question->id;
                if(isset($_POST["qno-$feedback_id"])){
                    $sdata['feedback_id'] = $feedback_id;
                    $sdata['answer'] = $_POST["qno-$feedback_id"];
                    $sdata['created_at'] = date('Y-m-d H:i:s');
                    
                    $details_inserted = $wpdb->insert('parent_feedback_items', $sdata, $sformat);
                }
            }
            unset($_SESSION['authenticated3']);
            echo '<script>
                alert(\'Feedback Submitted Successfully !\');
                window.location.href = "' . esc_url(home_url('/student-support/evaluation/college-evaluation/')) . '";
            </script>';
        } else {
            echo '<script>
                alert(\'Error submitting feedback. Please try again.\');
            </script>';
        }
    } else {
        echo '<script>
            alert(\'Please fill in all required fields.\');
        </script>';
    }
} ?>
<link rel="stylesheet" href="<?php echo esc_url(get_template_directory_uri()); ?>/css/department.css?version=1.3" type="text/css">
<link rel="stylesheet" href="<?php echo esc_url(get_template_directory_uri()); ?>/css/custom-header.css" type="text/css">
<div class="custom-head" style="background-image: url('<?php echo esc_url($featured_image_url); ?>');">
    <div class="overlay"></div>
    <div class="custom-head-content">
        <span class="page-title">College Evaluation</span>
    </div>
</div>
<div id="primary" class="content-area">
    <main id="main" class="site-main">
		<div class="dep-page form-pad">
            <div id="div-msg"></div>
            <div class="card card-primary feedback-form">
                <div class="card-body">
                    <? if (!isset($_SESSION['authenticated3']) || $_SESSION['authenticated3'] !== true) { ?>
                        <div class="row">
                            <div class="col-12 col-sm-4"></div>
                            <div class="col-12 col-sm-4">
                                <form method="POST">
                                    <p class="text-center"><b>Please Login to Continue...</b></p>
                                    <div class="form-group">
                                        <label for="username">Username</label>
                                        <input type="text" class="form-control" id="username" name="username" placeholder="Enter Username" autocomplete="off" required>
                                    </div>
                                    <div class="form-group">
                                        <label for="password">Password</label>
                                        <input type="password" class="form-control" id="password" name="password" placeholder="Password" autocomplete="off" required>
                                    </div>
                                    <button type="submit" class="btn btn-primary" name="login">Submit</button>
                                </form>
                            </div>
                        </div>
                        <? exit();
                    } ?>
                    <form method="POST">
                        <div class="row">
                            <div class="col-12 col-sm-4">
                                <div class="form-group">
                                    <label class="required" for="student">Student Name</label>
                                    <input type="text" class="form-control" name="student" id="student" required>
                                </div>
                            </div>
                            <div class="col-12 col-sm-4">
                                <div class="form-group">
                                    <label class="required" for="department">Department</label>
                                    <select class="form-control cdata" name="department" id="department" required>
                                        <option value="">Select</option>
                                        <? foreach($departments as $department){ ?>
                                            <option value="<?=$department->id;?>"><?=$department->name;?></option>
                                        <? } ?>
                                    </select>
                                </div>
                            </div>
                            <div class="col-12 col-sm-4">
                                <div class="form-group">
                                    <label class="required" for="ctype">Course Type</label>
                                    <select class="form-control cdata" name="ctype" id="ctype" required>
                                        <option value="">Select</option>
                                        <option value="UG Course">UG</option>
                                        <option value="PG Course">PG</option>
                                    </select>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-12 col-sm-4">
                                <div class="form-group">
                                    <label class="required" for="course">Course</label>
                                    <select class="form-control" name="course" id="course" required>
                                        <option value="">Select</option>
                                    </select>
                                </div>
                            </div>
                            <div class="col-12 col-sm-2">
                                <div class="form-group">
                                    <label class="required" for="semester">Semester</label>
                                    <select class="form-control" name="semester" id="semester" required>
                                        <option value="">Select</option>
                                        <option value="Semester 1">Semester 1</option>
                                        <option value="Semester 2">Semester 2</option>
                                        <option value="Semester 3">Semester 3</option>
                                        <option value="Semester 4">Semester 4</option>
                                        <option value="Semester 5">Semester 5</option>
                                        <option value="Semester 6">Semester 6</option>
                                        <option value="Semester 7">Semester 7</option>
                                        <option value="Semester 8">Semester 8</option>
                                    </select>
                                </div>
                            </div>
                            <div class="col-12 col-sm-2">
                                <div class="form-group">
                                    <label class="required" for="year">Year</label>
                                    <select class="form-control" name="year" id="year" required>
                                        <? for($i=date('Y'); $i >= 2022; $i--){ ?>
                                            <option value="<?=$i;?>"><?=$i.' - '.($i+1);?></option>
                                        <? } ?>
                                    </select>
                                </div>
                            </div>
                            <div class="col-12 col-sm-4">
                                <div class="form-group">
                                    <label class="required" for="parent">Parent Name</label>
                                    <input type="text" class="form-control" name="parent" id="parent" required>
                                </div>
                            </div>
                        </div>
                        <div style="width: 95%; margin-left: 20px;">
                            <? $i=0; foreach($questions as $question){ 
                                $i++;
                                $subquestions = $wpdb->get_results($wpdb->prepare("SELECT * FROM feedback WHERE type='1' and parent_id='$question->id' AND deleted_at IS NULL ORDER BY priority ASC, id ASC"));
                                ?>
                                <div class="row">
                                    <div class="col-12">
                                        <div class="form-group">
                                            <?=$i;?>. <?=$question->question;?>
                                        </div>
                                    </div>
                                </div>
                                <? if(empty($subquestions)){ ?>
                                    <div class="row">
                                        <? if($question->option1!=null){ ?>
                                            <div class="col-12 col-sm-3">
                                                <div class="form-group">
                                                    <input type="radio" name="qno-<?=$question->id;?>" id="qno-<?=$question->id;?>-1" value="1" required>
                                                    <label for="qno-<?=$question->id;?>-1"><?=$question->option1;?></label>
                                                </div>
                                            </div>
                                        <? } ?>
                                        <? if($question->option2!=null){ ?>
                                            <div class="col-12 col-sm-3">
                                                <div class="form-group">
                                                    <input type="radio" name="qno-<?=$question->id;?>" id="qno-<?=$question->id;?>-2" value="2" required>
                                                    <label for="qno-<?=$question->id;?>-2"><?=$question->option2;?></label>
                                                </div>
                                            </div>
                                        <? } ?>
                                        <? if($question->option3!=null){ ?>
                                            <div class="col-12 col-sm-3">
                                                <div class="form-group">
                                                    <input type="radio" name="qno-<?=$question->id;?>" id="qno-<?=$question->id;?>-3" value="3" required>
                                                    <label for="qno-<?=$question->id;?>-3"><?=$question->option3;?></label>
                                                </div>
                                            </div>
                                        <? } ?>
                                        <? if($question->option4!=null){ ?>
                                            <div class="col-12 col-sm-3">
                                                <div class="form-group">
                                                    <input type="radio" name="qno-<?=$question->id;?>" id="qno-<?=$question->id;?>-4" value="4" required>
                                                    <label for="qno-<?=$question->id;?>-4"><?=$question->option4;?></label>
                                                </div>
                                            </div>
                                        <? } ?>
                                        <? if($question->option5!=null){ ?>
                                            <div class="col-12 col-sm-3">
                                                <div class="form-group">
                                                    <input type="radio" name="qno-<?=$question->id;?>" id="qno-<?=$question->id;?>-5" value="5" required>
                                                    <label for="qno-<?=$question->id;?>-5"><?=$question->option5;?></label>
                                                </div>
                                            </div>
                                        <? } ?>
                                    </div>
                                <? }else{ ?>
                                    <? $j=0; foreach($subquestions as $subquestion){ $j++; ?>
                                        <div class="row" style="margin-left: 20px;">
                                            <div class="col-12">
                                                <div class="form-group">
                                                    <?=$j;?>. <?=$subquestion->question;?>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="row" style="margin-left: 20px;">
                                            <? if($subquestion->option1!=null){ ?>
                                                <div class="col-12 col-sm-3">
                                                    <div class="form-group">
                                                        <input type="radio" name="qno-<?=$subquestion->id;?>" id="qno-<?=$subquestion->id;?>-1" value="1" required>
                                                        <label for="qno-<?=$subquestion->id;?>-1"><?=$subquestion->option1;?></label>
                                                    </div>
                                                </div>
                                            <? } ?>
                                            <? if($subquestion->option2!=null){ ?>
                                                <div class="col-12 col-sm-3">
                                                    <div class="form-group">
                                                        <input type="radio" name="qno-<?=$subquestion->id;?>" id="qno-<?=$subquestion->id;?>-2" value="2" required>
                                                        <label for="qno-<?=$subquestion->id;?>-2"><?=$subquestion->option2;?></label>
                                                    </div>
                                                </div>
                                            <? } ?>
                                            <? if($subquestion->option3!=null){ ?>
                                                <div class="col-12 col-sm-3">
                                                    <div class="form-group">
                                                        <input type="radio" name="qno-<?=$subquestion->id;?>" id="qno-<?=$subquestion->id;?>-3" value="3" required>
                                                        <label for="qno-<?=$subquestion->id;?>-3"><?=$subquestion->option3;?></label>
                                                    </div>
                                                </div>
                                            <? } ?>
                                            <? if($subquestion->option4!=null){ ?>
                                                <div class="col-12 col-sm-3">
                                                    <div class="form-group">
                                                        <input type="radio" name="qno-<?=$subquestion->id;?>" id="qno-<?=$subquestion->id;?>-4" value="4" required>
                                                        <label for="qno-<?=$subquestion->id;?>-4"><?=$subquestion->option4;?></label>
                                                    </div>
                                                </div>
                                            <? } ?>
                                            <? if($subquestion->option5!=null){ ?>
                                                <div class="col-12 col-sm-3">
                                                    <div class="form-group">
                                                        <input type="radio" name="qno-<?=$subquestion->id;?>" id="qno-<?=$subquestion->id;?>-5" value="5" required>
                                                        <label for="qno-<?=$subquestion->id;?>-5"><?=$subquestion->option5;?></label>
                                                    </div>
                                                </div>
                                            <? } ?>
                                        </div>
                                    <? }?>
                                <? } ?>
                            <? } ?>
                            <div class="row">
                                <div class="col-12">
                                    <div class="form-group">
                                        <label for="comments">സെയ്ന്റ് ജോസഫ്സ് കോളേജിന്റെ സമഗ്ര അഭിവൃദ്ധി ഉയർത്താൻ താങ്കളുടെ ഭാഗത്തുനിന്നുള്ള നിർദേശങ്ങൾ പങ്കുവെക്കുക.</label>
                                        <textarea class="form-control" name="comments" id="comments" rows="4"></textarea>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-12">
                                <div class="form-group text-center">
                                    <button type="submit" name="btn_submit" class="btn btn-danger">Submit</button>
                                </div>
                            </div>
                        </div>
                    </form>
                </div>
            </div>
		</div>
    </main>
</div>
<script src="<?php echo esc_url(get_template_directory_uri()); ?>/js/feedback.js?version=1.1"></script>
<?php 
get_footer();