<?php
/**
 * Template Name: Exam Time Table Page
 *
 * Description: This is a custom template for displaying exam timetable page.
 */
get_header();

$featured_image_url = esc_url(wp_upload_dir()['baseurl'].'/2025/05/casc.jpg');
if (has_post_thumbnail()) {
    $featured_image_id = get_post_thumbnail_id();
    $featured_image_url = wp_get_attachment_url($featured_image_id);
}

global $wpdb;

$departments = $wpdb->get_results($wpdb->prepare("SELECT * FROM departments WHERE deleted_at IS NULL ORDER BY name"));
$courses = $wpdb->get_results($wpdb->prepare("SELECT * FROM courses WHERE deleted_at IS NULL ORDER BY name"));
$semesters = ['Semester I', 'Semester II', 'Semester III', 'Semester IV', 'Semester V', 'Semester VI',];

?>
<link rel="stylesheet" href="<?php echo esc_url(get_template_directory_uri()); ?>/css/department.css" type="text/css">
<link rel="stylesheet" href="<?php echo esc_url(get_template_directory_uri()); ?>/css/custom-header.css" type="text/css">
<div class="custom-head" style="background-image: url('<?php echo esc_url($featured_image_url); ?>');">
    <div class="overlay"></div>
    <div class="custom-head-content">
        <span class="page-title">Academics</span>
    </div>
</div>
<div id="primary" class="content-area">
    <main id="main" class="site-main">
		<div class="dep-menus">
			<ul class="dep-menus-list">
				<li><a href="<?php echo esc_url(home_url('/academics/programmes/')); ?>"><div class="dep-menu-icon <?php if(is_page('programmes')){ echo 'ic-active'; } ?>"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/icons/graduation.svg" alt="Programmes"></div><span>PROGRAMMES</span></a></li>
				<li><a href="<?php echo esc_url(home_url('/academics/add-on-courses/')); ?>"><div class="dep-menu-icon <?php if(is_page('add-on-courses')){ echo 'ic-active'; } ?>"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/icons/addon.svg" alt="Add-on Courses"></div><span>ADD-ON COURSES</span></a></li>
				<li><a href="<?php echo esc_url(home_url('/academics/roll-of-honour/')); ?>"><div class="dep-menu-icon <?php if(is_page('roll-of-honour')){ echo 'ic-active'; } ?>"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/icons/honour.svg" alt="Roll of Honour"></div><span>ROLL OF HONOUR</span></a></li>
				<li><a href="<?php echo esc_url(home_url('/academics/exam-time-table/')); ?>"><div class="dep-menu-icon <?php if(is_page('exam-time-table')){ echo 'ic-active'; } ?>"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/icons/table.svg" alt="Exam Time Table"></div><span>EXAM TIME TABLE</span></a></li>
				<li><a href="<?php echo esc_url(home_url('/academics/examination-calendar/')); ?>"><div class="dep-menu-icon <?php if(is_page('examination-calendar')){ echo 'ic-active'; } ?>"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/icons/calendar.svg" alt="Examination Calendar"></div><span>EXAMINATION CALENDAR</span></a></li>
				<li><a href="<?php echo esc_url(home_url('/academics/college-handbook/')); ?>"><div class="dep-menu-icon <?php if(is_page('college-handbook')){ echo 'ic-active'; } ?>"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/icons/book.svg" alt="College Handbook"></div><span>COLLEGE HANDBOOK</span></a></li>
				<li><a href="<?php echo esc_url(home_url('/academics/academic-calendar/')); ?>"><div class="dep-menu-icon <?php if(is_page('academic-calendar')){ echo 'ic-active'; } ?>"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/icons/calendar.svg" alt="Academic Calendar"></div><span>ACADEMIC CALENDAR</span></a></li>
				<li><a href="http://www.exam.kannuruniversity.ac.in/" target="_blank"><div class="dep-menu-icon"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/icons/web.svg" alt="University Exam Portal"></div><span>UNIVERSITY EXAM PORTAL</span></a></li>
			</ul>
		</div>
		<div class="dep-title"><?php echo esc_html(get_the_title()); ?></div>
		<div class="dep-page">
		    <div class="filters bg-primary" style="padding: 30px; border-radius: 10px;">
                <div class="row">
                    <div class="col-12 col-sm-3">
                        <div class="form-group">
                            <label for="department">Deparment</label>
                            <select class="form-control" id="department">
                                <option value="">Select</option>
                                <? foreach($departments as $department): ?>
                                    <option value="<?=$department->id;?>"><?=$department->name;?></option>
                                <? endforeach; ?>
                            </select>
                        </div>
                    </div>
                    <div class="col-12 col-sm-3">
                        <div class="form-group">
                            <label for="course">Course</label>
                            <select class="form-control" id="course">
                                <option value="">Select</option>
                                <? foreach($courses as $course): ?>
                                    <option value="<?=$course->id;?>"><?=$course->name;?></option>
                                <? endforeach; ?>
                            </select>
                        </div>
                    </div>
                    <div class="col-12 col-sm-6">
                        <div class="form-group">
                            <label for="semester">Semester</label>
                            <div class="row">
                                <div class="col-12 col-sm-6">
                                    <div class="form-group">
                                        <select class="form-control" id="semester">
                                            <option value="">Select</option>
                                            <option value="Semester I">Semester I</option>
                                            <option value="Semester II">Semester II</option>
                                            <option value="Semester III">Semester III</option>
                                            <option value="Semester IV">Semester IV</option>
                                            <option value="Semester V">Semester V</option>
                                            <option value="Semester VI">Semester VI</option>
                                        </select>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-6">
                                    <div class="form-group">
                                        <button type="button" class="btn btn-danger" id="getData">Filter</button>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <br>
            <div id="results" style="padding:30px;">
                <div id="loading" style="display: none;">Loading</div>
            </div>
		</div>
    </main>
</div>
<script>
    $(document).ready(function(){
        $("#getData").click(function(){
            getExams();
        });
    });
    
    function getExams(){
        var department = $("#department").val();
        var course = $("#course").val();
        var semester = $("#semester").val();
        
        $('#loading').show();
        
        $.ajax({
            url: 'https://chinmayaportal.relents.in/api/exams',
            type: 'GET',
            data: { department:department, course:course, semester:semester },
            success: function(response){
                $("#results").html(response);
            },
            error: function(xhr, status, error) {
                console.log('Error:', error);
            },
            complete: function() {
                $('#loading').hide();
            }
        });
    }
    
    getExams();
    
</script>
<?php 
get_footer();