<?php
/**
 * SJC functions and definitions
 *
 * @package SJC
 */
 
define('UPLOADS_URL', 'https://chinmayaportal.relents.in/public/uploads/');
 
add_theme_support( 'title-tag' );

add_theme_support('post-thumbnails');

add_theme_support('menus');

add_theme_support( 'custom-logo' );

function my_theme_enqueue_styles() {
    wp_enqueue_style('my-theme-style', get_stylesheet_uri());
    wp_enqueue_style('custom-style',  get_template_directory_uri().'/css/style.css?version=1.65');
}

function custom_scripts() {
    wp_enqueue_script('custom-script',  get_template_directory_uri().'/script.js', array(), '1.0', true);
    wp_enqueue_script('my-script',  get_template_directory_uri().'/js/script.js', array(), '1.2', true);
}
add_action('wp_enqueue_scripts', 'my_theme_enqueue_styles', 'custom_scripts');

function navmenu_shortcode() {
	ob_start();
	global $wpdb;
	$results = $wpdb->get_results($wpdb->prepare("SELECT * FROM committees WHERE deleted_at IS NULL"));
	$facilities = $wpdb->get_results($wpdb->prepare("SELECT * FROM facilities WHERE id > 3 AND deleted_at IS NULL"));
	$supports = $wpdb->get_results($wpdb->prepare("SELECT * FROM supports WHERE stype='General' AND deleted_at IS NULL"));
	$associations = $wpdb->get_results($wpdb->prepare("SELECT * FROM supports WHERE stype='Association' AND deleted_at IS NULL"));
	$clubs = $wpdb->get_results($wpdb->prepare("SELECT * FROM supports WHERE stype='Club' AND deleted_at IS NULL"));
	
	$content = get_template_directory().'/template-parts/menu.php';
    if (file_exists($content)) {
        include $content;
    }
    $output = ob_get_clean();
    return $output;
}

add_shortcode('navmenu', 'navmenu_shortcode');

function wpb_track_visitors() {
    if( !is_admin() ) {
        $count_key = 'visitor_count';
        $count = get_option($count_key);
        $count = (int)$count + 1;
        update_option( $count_key, $count );
    }
}
add_action( 'wp_head', 'wpb_track_visitors' );

function start_session_if_needed() {
    if (session_status() == PHP_SESSION_NONE) {
        session_start();
    }
}
add_action('init', 'start_session_if_needed'); // Ensure the session is started early

// Function to update and display the visitor count
function wpb_display_visitor_count() {
    // Define the option key to store the count
    $count_key = 'visitor_count';
    $count = get_option($count_key); // Retrieve the current visitor count
    
    if ($count === false) {
        $count = 0; // If no count exists, initialize it to 0
    }

    // Increment the visitor count only on the homepage and if the session variable is not set
    if (is_front_page() && !isset($_SESSION['visited'])) {
        // Increment the count
        $count++;
        
        // Save the updated count to the database
        update_option($count_key, $count);

        // Set a session variable to prevent multiple increments during the same session
        $_SESSION['visited'] = true;
    }

    return $count;
}

function visitors_shortcode(){
    wp_enqueue_script('visitor-script', get_template_directory_uri().'/js/visitor.js?version=1.3', array(), '1.6', true);
    
    $visitors = wpb_display_visitor_count();
    $output = '<div class="visitor">
                    <div class="visitor-item">
                        <div class="visitor-count" id="count">'.$visitors.'</div>
                        <div class="visitor-title">Visitors</div>
                    </div>
                </div>';
    return $output;
}

add_shortcode('visitors', 'visitors_shortcode');

function slider_shortcode(){
    wp_enqueue_script('slider-script', get_template_directory_uri().'/js/slider.js', array(), '1.0', true);
        
    global $wpdb;
    $url = UPLOADS_URL;
    
    $output = '';
    $results = $wpdb->get_results($wpdb->prepare("SELECT * FROM sliders WHERE deleted_at IS NULL"));
    if($results){
        $output .= '<div class="sjc-slider">
                        <div class="sjc-slides">';
                            foreach ($results as $row){
                                $output .= '<div class="sjc-slide sjc-slide-active">
                                        <img src="'.$url.$row->image.'" alt="'.$row->title.'">
                                    </div>';
                            }
        $output .=      '</div>
                    </div>';
    }
    
    wp_reset_postdata();
	return $output;
}

add_shortcode('slider', 'slider_shortcode');

function notification_scroll_shortcode(){
    
    global $wpdb;
    
	wp_enqueue_style('notification-style', get_template_directory_uri().'/css/notification.css?ver=1.2');

    $results = $wpdb->get_results($wpdb->prepare("SELECT * FROM notifications WHERE deleted_at IS NULL ORDER BY id DESC"));
	$output = '<div class="notification">
                    <div class="notification-header">
                        <div class="notification-title"><i class="fa-solid fa-bullhorn"></i>Latest News</div>
                    </div>
                    <div class="notification-content"><marquee><div class="notification-scroll">';
    if($results) {
        foreach($results as $result) {
            $output .=  '<div class="notification-item"><i class="fa-solid fa-angles-right"></i>'.esc_html($result->title).'</div>';
        }
    }
    $output .=       '</div></marquee></div>
                </div>';
    
	wp_reset_postdata();
	return $output;
}

add_shortcode('notification_scroll', 'notification_scroll_shortcode');

function testimonial_slider_shortcode(){
    wp_enqueue_script('testimonial-script', get_template_directory_uri().'/js/testimonial.js', array(), '1.0', true);

    global $wpdb;
    $url = UPLOADS_URL;

	$output = '';
    $results = $wpdb->get_results($wpdb->prepare("SELECT * FROM testimonials WHERE deleted_at IS NULL"));
	if($results){
        $output .=  '<div class="sjc-testimonial">
                    <div class="sjc-testimonial-header">
                        <div class="sjc-testimonial-title">Quotes by Swami Chinmayananda</div>
                        <div class="sjc-testimonial-tools">
                            <i class="fa-solid fa-square-caret-left" id="lcontrol1"></i>
                            <i class="fa-solid fa-square-caret-right" id="lcontrol2"></i>
                        </div>
                    </div>
					<div class="sjc-testimonial-body">
                        <div class="sjc-testimonial-container">
                            <div class="sjc-testimonial-content">';
                                foreach ($results as $row){
                                    $output .= '<div class="sjc-testimonial-item">
                                        <div class="sjc-testimonial-item-content"> " '.$row->message.' "</div>
                                        <div class="sjc-testimonial-item-thumb"><img src="'.$url.$row->image.'"></div>
                                        <div class="sjc-testimonial-item-title">'.$row->name.'</div>
                                        <div class="sjc-testimonial-item-designation">'.$row->designation.'</div>
                                        <div class="sjc-testimonial-item-company">'.$row->company.'</div>
                                    </div>';
                                }
                            $output .= '</div>
                        </div>
                    </div>
				</div>';
	}
        
    wp_reset_postdata();
	return $output;
}
add_shortcode('testimonial_slider', 'testimonial_slider_shortcode');

function message_slider_shortcode(){
    wp_enqueue_script('message-script', get_template_directory_uri().'/js/message.js', array(), '1.0', true);

    global $wpdb;
    $url = UPLOADS_URL;

	$output = '';
    $results = $wpdb->get_results($wpdb->prepare("SELECT * FROM messages WHERE deleted_at IS NULL"));
	if($results){
        $output .=  '<div class="sjc-message">
                        <div class="sjc-message-body">
                            <div class="sjc-message-container">
                                <div class="sjc-message-content">';
                                    foreach ($results as $row){
                                        $output .= '<div class="sjc-message-item">
                                            <div class="sjc-message-item-title">'.$row->title.'</div>
                                            <div class="sjc-message-item-content"> " '.$row->message.' "</div>
                                            <div class="sjc-message-item-thumb"><img src="'.$url.$row->image.'"></div>
                                            <div class="sjc-message-item-name">'.$row->name.'</div>
                                            <div class="sjc-message-item-designation">'.$row->designation.'</div>
                                        </div>';
                                    }
                                $output .= '</div>
                            </div>
                        </div>
                    </div>';
	}
        
    wp_reset_postdata();
	return $output;
}
add_shortcode('message_slider', 'message_slider_shortcode');

function event_grid_shortcode($atts){
    global $wpdb;
    $url = UPLOADS_URL;
    
    $count=10;
    if($atts['count']!=''){
        $count = $atts['count'];
    }
    $cond = ''; $department='';
    if($atts['department']!=''){
        $department = $atts['department'];
        $cond .= " and JSON_CONTAINS(departments,'\"$department\"')";
    }
    $output = '';
    $results = $wpdb->get_results($wpdb->prepare("SELECT * FROM events WHERE deleted_at IS NULL $cond order by date desc limit $count"));
	if($results){
        $output .=  '<div class="sjc-event">
                        <div class="sjc-event-body">
                            <div class="sjc-event-container">';
                                foreach ($results as $row){
                                    $output .= '<div class="sjc-event-item">
                                                    <div class="sjc-event-item-thumb"><img src="'.$url.$row->image.'"></div>
                                                    <div class="sjc-event-item-date">
                                                        <div class="sjc-event-item-day">'.date('d',strtotime($row->date)).'</div>
                                                        <div class="sjc-event-item-month">'.date('M Y',strtotime($row->date)).'</div>
                                                    </div>
                                                    <div class="sjc-event-item-title">'.$row->title.'</div>
                                                    <div class="sjc-event-item-content">'.wp_trim_words( $row->description, 25,'...').'</div>
                                                    <div class="sjc-event-item-view"><a class="sjc-event-item-button" href="'.get_site_url().'/event/?id='.$row->id.'">Read More</a></div>
                                                </div>';
                                }
                            $output .= '</div>
                        </div>
                        <div class="sjc-event-footer">
                            <a class="sjc-event-view" href="'.get_site_url().'/events/?did='.$department.'">View More</a>
                        </div>
                    </div>';
	}
        
	wp_reset_postdata();
	return $output;
}
add_shortcode('event_grid', 'event_grid_shortcode');

function news_scroll_shortcode(){
    
    global $wpdb;
    
	wp_enqueue_style('news-style', get_template_directory_uri().'/css/news.css');

	$output = '<div class="news">
                    <div class="news-header">
                        <div class="news-title">Latest News</div>
                    </div>
                    <div class="news-body">
                        <div class="news-content">';
	$results = $wpdb->get_results($wpdb->prepare("SELECT * FROM news WHERE deleted_at IS NULL ORDER BY date DESC"));
	if($results){
        foreach ($results as $row){
            $output .= '<div class="news-item">
                            <div class="news-item-date">
                                <div class="news-item-day">'.date('d', strtotime($row->date)).'</div>
                                <div class="news-item-month">'.strtoupper(date('M Y', strtotime($row->date))).'</div>
                            </div>
                            <div class="news-item-content">
                                <div class="news-item-title"><a href="'.get_site_url().'/news/?id='.$row->id.'">'.$row->title.'</a></div>
                                <div class="news-item-description">'.$row->description.'</div>
                            </div>
                        </div>';
        }
	}
    
    $output .= '</div>
            </div>
            <div class="news-footer">
                <div class="news-view"><a href="'.get_site_url().'/news-all/">View All</a></div>
            </div>
        </div>';
        
	wp_reset_postdata();
	return $output;
}

add_shortcode('news_scroll', 'news_scroll_shortcode');

function event_scroll_shortcode(){
    
    global $wpdb;
    $cdate = date('Y-m-d');
    
	wp_enqueue_style('news-style', get_template_directory_uri().'/css/news.css');

	$output = '<div class="news">
                    <div class="news-header">
                        <div class="news-title">Upcoming Events</div>
                    </div>
                    <div class="news-body">
                        <div class="news-content">';
	$results = $wpdb->get_results($wpdb->prepare("SELECT * FROM events WHERE date >= '$cdate' AND deleted_at IS NULL ORDER BY date DESC"));
	if($results){
        foreach ($results as $row){
            $output .= '<div class="news-item">
                            <div class="news-item-date">
                                <div class="news-item-day">'.date('d', strtotime($row->date)).'</div>
                                <div class="news-item-month">'.strtoupper(date('M Y', strtotime($row->date))).'</div>
                            </div>
                            <div class="news-item-content">
                                <div class="news-item-title"><a href="'.get_site_url().'/event/?id='.$row->id.'">'.$row->title.'</a></div>
                                <div class="news-item-description">'.$row->description.'</div>
                            </div>
                        </div>';
        }
	}
    
    $output .= '</div>
            </div>
            <div class="news-footer">
                <div class="news-view"><a href="'.get_site_url().'/events/">View All</a></div>
            </div>
        </div>';
        
	wp_reset_postdata();
	return $output;
}

add_shortcode('event_scroll', 'event_scroll_shortcode');

function banner_shortcode(){
        
    global $wpdb;
    $url = UPLOADS_URL;
    wp_enqueue_style('banner-style', get_template_directory_uri().'/css/banner.css');
    wp_enqueue_script('banner-script', get_template_directory_uri().'/js/banner.js', array(), '1.0', true);
    
    $output = '';
    $results = $wpdb->get_results($wpdb->prepare("SELECT * FROM banners WHERE deleted_at IS NULL"));
    if($results){
        $output .= '<div class="banner-content">
                        <div class="banners">';
                            foreach ($results as $row){
                                $output .= '<div class="banner active">
                                        <img src="'.$url.$row->image.'" alt="'.$row->title.'">
                                    </div>';
                            }
        $output .=      '</div>
                    </div>';
    }
        
    wp_reset_postdata();
	return $output;
}

add_shortcode('banner', 'banner_shortcode');

function team_grid_shortcode($atts){
    
    global $wpdb;
    $url = UPLOADS_URL;
    wp_enqueue_style('team-style', get_template_directory_uri().'/css/team.css');
    
    $cond = '';
    if($atts['committee']!=''){
        $cond = " and committee='$atts[committee]'";
    }
    
    $output = '';
    $results = $wpdb->get_results($wpdb->prepare("SELECT * FROM executives WHERE deleted_at IS NULL $cond order by priority asc"));
    $output .=  '<div class="team-grid">';
    foreach ($results as $row){
        $image = 'dummy-user.jpg';
        if($row->image){ $image = $row->image; }
        $name = $row->name ?? ' ';
        $row1 = $row->row1 ?? '&nbsp;';
        $row2 = $row->row2 ?? '&nbsp;';
        $row3 = $row->row3 ?? '&nbsp;';
        $output .=  '<div class="team-item">
                        <div class="team-image"><img src="'.$url.$image.'" alt="'.$name.'"></div>
                        <div class="team-title">'.strtoupper($name).'</div>
                        <div class="team-description">'.$row1.'</div>
                        <div class="team-description">'.$row2.'</div>
                        <div class="team-description">'.$row3.'</div>
                    </div>';
    }
    $output .=  '</div>';
    
    wp_reset_postdata();
	return $output;
}

add_shortcode('team_grid', 'team_grid_shortcode');

function honour_shortcode($atts=array()){
    
    global $wpdb;
    $url = UPLOADS_URL;
    wp_enqueue_style('team-style', get_template_directory_uri().'/css/honour.css');
    
    $cond = '';
    if($atts['department']!=''){
        $cond = " and id='$atts[department]'";
    }
    
    $output = '';
    $results = $wpdb->get_results($wpdb->prepare("SELECT * FROM departments WHERE deleted_at IS NULL $cond order by id asc"));
    if(!empty($results)){
        foreach($results as $result){
            $did = $result->id;
            $results1 = $wpdb->get_results($wpdb->prepare("SELECT * FROM results WHERE department_id='$did' and deleted_at IS NULL order by id desc"));
            if(!empty($results1)){
                $output .=  '<div class="row mt-5">
                                <div class="col-12 p-5">
                                    <div class="honour-department">DEPARTMENT OF '.strtoupper($result->name).'</div>
                                </div>
                            </div>
                            <div class="row mt-5">
                                <div class="col-12 p-5">
                                    <div class="honour-grid">';
                                        foreach($results1 as $result1){
                                            $image = 'dummy-user.jpg';
                                            if($result1->image){ $image = $result1->image; }
                                            $name = $result1->name ?? '&nbsp;';
                                            $position = $result1->position ?? '&nbsp;';
                                            $percentage = $result1->percentage ? '('.$result1->percentage.')':'&nbsp;';
                                            $course = $result1->course ?? '&nbsp;';
                                            $year = $result1->year ?? '&nbsp;';
                                            
                                            $output .=  '<div class="honour-item">
                                                <div class="honour-image"><img src="'.$url.$image.'" alt="'.$name.'"></div>
                                                <div class="honour-title">'.strtoupper($name).'</div>
                                                <div class="honour-description">'.$position.' '.$percentage.'</div>
                                                <div class="honour-description">'.$course.'</div>
                                                <div class="honour-description">'.$year.'</div>
                                            </div>';
                                        }
                $output .=          '</div>
                                </div>
                            </div>';
            }
        }
    }
    
    wp_reset_postdata();
	return $output;
}

add_shortcode('honour', 'honour_shortcode');

function academic_calendar_shortcode(){
    global $wpdb;
    $url = UPLOADS_URL;
    wp_enqueue_style('team-style', get_template_directory_uri().'/css/honour.css');
    
    $output = '';
    $results = $wpdb->get_results($wpdb->prepare("SELECT * FROM calendars WHERE deleted_at IS NULL order by id desc"));
    if(!empty($results)){
        $output .= '<div class="row">
                        <div class="col-12">
                            <table class="table table-bordered">
                                <thead>
                                    <th>Title</th>
                                    <th>Attachment</th>
                                </thead>
                                <tbody>';
                                foreach($results as $result){
                                    $title = $result->title ?? '&nbsp;';
                                    $attachment = $result->attachment ?? '&nbsp;';
                                    $output .= '<tr>
                                                    <td>'.$title.'</td>
                                                    <td><a href="'.$url.$attachment.'" class="btn btn-success">View</a></td>
                                                </tr>';
                                }
        $output .=              '</tbody>
                            </table>
                        </div>
                    </div>';
    }
    
    wp_reset_postdata();
	return $output;
}

add_shortcode('academic_calendar', 'academic_calendar_shortcode');

function faculty_grid_shortcode($atts){
    
    global $wpdb;
    $url = UPLOADS_URL;
    wp_enqueue_style('faculty-style', get_template_directory_uri().'/css/faculty.css');
    
    $cond = '';
    if($atts['department']!=''){
        $cond = " and department_id='$atts[department]'";
    }
    
    $output = '';
    $results = $wpdb->get_results($wpdb->prepare("SELECT * FROM faculties WHERE deleted_at IS NULL $cond order by priority asc"));
    $output .=  '<div class="faculty-grid">';
    foreach ($results as $row){
        $image = 'dummy-user.jpg';
        if($row->image){ $image = $row->image; }
        
        $name = $row->name ?? ' ';
        $designation = $row->designation ?? '&nbsp;';
        
        $output .=  '<div class="faculty-item">
                        <div class="faculty-image"><img src="'.$url.$image.'" alt="'.$name.'"></div>
                        <div class="faculty-title">'.strtoupper($name).'</div>
                        <div class="faculty-description">'.$designation.'</div>
                        <div class="faculty-view"><a href="#" target="_blank" class="faculty-btn">View</a></div>
                    </div>';
    }
    $output .=  '</div>';
    
    wp_reset_postdata();
	return $output;
}

add_shortcode('faculty_grid', 'faculty_grid_shortcode');

function batch_photo_shortcode($atts){
    
    global $wpdb;
    $url = UPLOADS_URL;
    wp_enqueue_style('batchphoto-style', get_template_directory_uri().'/css/batchphoto.css');
    wp_enqueue_script('batchphoto-script', get_template_directory_uri().'/js/batchphoto.js', array(), '1.0', true);
    
    $cond = '';
    if($atts['department']!=''){
        $cond = " and department_id='$atts[department]'";
    }
        
    $output = '';
    $results = $wpdb->get_results($wpdb->prepare("SELECT * FROM batchphotos WHERE deleted_at IS NULL $cond order by id desc"));
    $output .=  '<div class="batchphoto">';
    foreach ($results as $row){
        $batch = $row->batch ?? '&nbsp;';
        $course = $row->course ?? '&nbsp;';
        $image = $row->image;
        $output .=  '<div class="batchphoto-item">
                        <div class="batchphoto-image"><img decoding="async" src="'.$url.$image.'" alt="'.$batch.'" onclick="openModal(this)"></div>
                        <div class="batchphoto-det">
                            <div class="batchphoto-batch">'.strtoupper($batch).'</div>
                            <div class="batchphoto-course">'.$course.'</div>
                        </div>
                    </div>';
    }
    $output .=  '</div>
                <div id="imageModal" style="display:none;">
                    <span onclick="closeModal()" style="cursor:pointer;">&times;</span>
                    <img id="modalImage" style="width:100%;">
                </div>';
        
    wp_reset_postdata();
	return $output;
}

add_shortcode('batch_photo', 'batch_photo_shortcode');

function committee_grid_shortcode($atts){
    
    global $wpdb;
    $url = UPLOADS_URL;
    wp_enqueue_style('team-style', get_template_directory_uri().'/css/members.css');
    
    $cond = '';
    if($atts['id']!=''){
        $cond = " and committee_id='$atts[id]'";
    }
    
    $output = '';
    $results = $wpdb->get_results($wpdb->prepare("SELECT * FROM members WHERE deleted_at IS NULL $cond order by priority asc"));
    $output .=  '<div class="team-grid">';
    foreach ($results as $row){
        $image = 'dummy-user.jpg';
        if($row->image){ $image = $row->image; }
        
        $name = $row->name ?? ' ';
        $row1 = $row->row1 ?? '&nbsp;';
        $row2 = $row->row2 ?? '&nbsp;';
        $row3 = $row->row3 ?? '&nbsp;';
        
        $output .=  '<div class="team-item">
                        <div class="team-image"><img src="'.$url.$image.'" alt="'.$name.'"></div>
                        <div class="team-title">'.strtoupper($name).'</div>
                        <div class="team-description">'.$row1.'</div>
                        <div class="team-description">'.$row2.'</div>
                        <div class="team-description">'.$row3.'</div>
                    </div>';
    }
    $output .=  '</div>';
    
    wp_reset_postdata();
	return $output;
}

add_shortcode('committee_grid', 'committee_grid_shortcode');

function achievement_shortcode($atts){
    
    global $wpdb;
    $url = UPLOADS_URL;
    wp_enqueue_style('achievement-style', get_template_directory_uri().'/css/achievement.css');
    
    $cond = '';
    if($atts['department']!=''){
        $cond = " and department_id='$atts[department]'";
    }
    
    $output = '';
    $results = $wpdb->get_results($wpdb->prepare("SELECT * FROM achievements WHERE deleted_at IS NULL $cond order by id desc"));
    $output .=  '<div class="achievement">';
    foreach ($results as $row){
        $name = $row->name ?? '&nbsp;';
        $desc = $row->description ?? '&nbsp;';
        $image = $row->image;
        
        $output .=  '<div class="achievement-item">
                        <div class="achievement-image"><img decoding="async" src="'.$url.$image.'" alt="'.$name.'"></div>
                        <div class="achievement-det">
                            <div class="achievement-name">'.strtoupper($name).'</div>
                            <div class="achievement-desc">'.$desc.'</div>
                        </div>
                    </div>';
    }
    $output .=  '</div>';
    
    wp_reset_postdata();
	return $output;
}

add_shortcode('achievement', 'achievement_shortcode');

function course_shortcode($atts){
    
    global $wpdb;
    $url = UPLOADS_URL;
    
    $cond = '';
    if($atts['department']!=''){
        $cond = " and department_id='$atts[department]'";
    }
    if($atts['ctype']!=''){
        $cond = " and ctype='$atts[ctype]'";
    }
    
    $output = '';
    $results = $wpdb->get_results($wpdb->prepare("SELECT * FROM courses WHERE deleted_at IS NULL $cond order by id asc"));
    $output .=  '<div class="row">';
    $i=0;
    foreach ($results as $row){
        $name = $row->name ?? '&nbsp;';
        $seats = $row->seats ?? '&nbsp;';
        $eligibility = $row->eligibility ?? null;
        $subjects = $row->subjects ?? null;
        $duration = $row->duration;
        $syllabus = $row->syllabus;
        $poco = $row->poco;
        
        $output .=  '<div class="col-12 col-sm-6">
                        <div class="course-item">
                            <div class="course-title">'.$name.'</div>
                            <div class="row">
                                <div class="col-12 col-sm-3 course-seat-block">
                                    <div class="course-seat">
                                        <div class="course-seat-count">'.$seats.'</div>
                                        Seats
                                    </div>
                                </div>
                                <div class="col-12 col-sm-9 p-10">';
                                    if($eligibility){
                                        $output .= '<div class="course-heading">Eligibility for Admission</div>
                                                    <div class="course-content">'.$eligibility.'</div>';
                                    }
                                    if($subjects){
                                        $output .= '<div class="course-heading">Complementary Subjects</div>
                                                    <div class="course-content">'.$subjects.'</div>';
                                    }
                                    if($duration){
                                        $output .= '<div class="course-heading">Duration</div>
                                                    <div class="course-content">'.$duration.'</div>';
                                    }
                                    if($syllabus){
                                        $output .= '<a href="'.$url.$syllabus.'" class="course-button" target="_blank">Syllabus</a>';
                                    }
                                    if($poco){
                                        $output .= '<a href="'.$url.$poco.'" class="course-button" target="_blank">POs, PSOs & COs</a>';
                                    }
                                $output .= '</div>
                            </div>
                        </div>
                    </div>';
                    
        if($i%2!=0){
            $output .= '</div><div class="row">';
        }
        $i++;
    }
    $output .=  '</div>';
    
    wp_reset_postdata();
	return $output;
}

add_shortcode('course', 'course_shortcode');

function fee_structure_shortcode(){
    
    global $wpdb;
    $url = UPLOADS_URL;
    $output='';
    $results = $wpdb->get_results($wpdb->prepare("SELECT * FROM fee_structures WHERE deleted_at IS NULL ORDER BY id asc"));
    foreach($results as $row){
        $title = $row->title ?? '';
        $image = $row->image ?? '';
        
        $output .=  '<div class="row">
                        <div class="col-12 text-center"><b>'.$title.'</b></div>
                    </div>
                    <div class="row">
                        <div class="col-12">
                            <img src="'.$url.$image.'" loading="lazy" width="100%">
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-12">
                            <hr>
                        </div>
                    </div>';
    }
    
    wp_reset_postdata();
	return $output;
}

add_shortcode('fee_structure', 'fee_structure_shortcode');

function book_carosel_shortcode(){
    wp_enqueue_style( 'post-style', get_template_directory_uri().'/css/library.css?version=1.2' );
	wp_enqueue_script('post-script', get_template_directory_uri().'/js/library.js?version=1.3', array(), '1.0', true);

	global $wpdb;
    $url = UPLOADS_URL;
    
    $results = $wpdb->get_results($wpdb->prepare("SELECT * FROM library_books WHERE deleted_at IS NULL ORDER BY id asc"));
	$output .= '<div class="library-slider">
                    <div class="library-header">
						<div class="library-title">New Arrivals</div>
						<div class="library-tools">
                            <div class="library-controls"><i class="fa-solid fa-square-caret-left" id="lcontrol1"></i><i class="fa-solid fa-square-caret-right" id="lcontrol2"></i></div>
                        </div>
					</div>
					<div class="library-body">
						<div class="library-container">
							<div class="library-content">';
								if($results){
									foreach($results as $result){
									    $title = $result->title ?? '';
										$image = $result->image ?? '';
										$output .= '<div class="library-item" title="'.$title.'"><img src="'.$url.$image.'" loading="lazy"></div>';
									}
								}
    $output .=              '</div>
						</div>
					</div>
				</div>';
				
	wp_reset_postdata();

	return $output;
}

add_shortcode('book_carosel', 'book_carosel_shortcode');

function library_evaluation_shortcode(){
    wp_enqueue_script('chart-script', get_template_directory_uri().'/js/chart.js', array(), '1.0', true);
    wp_enqueue_script('evaluation-script', get_template_directory_uri().'/js/evaluation.js', array(), '1.455', true);
	
	global $wpdb;
    $url = UPLOADS_URL;
    $output = '';
    $results = $wpdb->get_results($wpdb->prepare("SELECT * FROM library_questions WHERE qtype=0 ORDER BY id ASC"));
	if($results){
        $output .= '<div class="row">
                        <div class="col-12 col-sm-3">';
                            foreach($results as $result){
                                $output .= '<button type="button" class="btn btn-default btn-block btn-lib" id="btn-'.$result->id.'" onclick="getQuestion('.$result->id.')">Criteria '.$result->qno.'</button>';
                            }
        $output .=      '</div>
                        <div class="col-12 col-sm-9" style="margin-top: 10px;">
                            <div class="row">
                                <div class="col-12 col-sm-2">
                                    <label for="year">Year</label>
                                </div>
                                <div class="col-12 col-sm-3">
                                    <select class="form-control" id="year">
                                        <option value="">All</option>';
                                        for($i=date('Y'); $i >= 2022; $i--){ 
                                            $output .= '<option value="'.$i.'">'.$i.' - '.($i+1).'</option>';
                                        }
                                    $output .= '</select>
                                </div>
                            </div>
                            <br>
                            <div class="row">
                                <div class="col-12">
                                    <div id="question"></div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12">
                                    <div style="margin-top: 30px;">
                                        <canvas id="myChart"></canvas>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>';
	}

	wp_reset_postdata();

	return $output;
}

add_shortcode('library_evaluation', 'library_evaluation_shortcode');

function mandatory_disclosure_shortcode(){
    global $wpdb;
    $url = UPLOADS_URL;
    
    $row = $wpdb->get_row($wpdb->prepare("SELECT * FROM disclosures WHERE deleted_at IS NULL ORDER BY id ASC"));
	if($row && $row->attachment!=''){
        $output .= '<div class="row">
                        <div class="col-12">
                            <table width="100%">
                                <tr>
                                    <td width="70%"><i class="fa-solid fa-file-pdf text-danger" style="font-size: 24px;"></i> <span style="font-size: 20px; font-weight: 500; margin-left: 10px;">'.$row->title.'</span></td>
                                    <td width="30%" align="center"><a href="'.$url.$row->attachment.'" class="btn btn-danger" title="Attachment">Download</a></td>
                                </tr>
                            </table>
                            <br>
                            <embed src="'.$url.$row->attachment.'" width="500" height="500" type="application/pdf">
                        </div>
                    </div>';
    }
    
    wp_reset_postdata();

	return $output;
}

add_shortcode('mandatory_disclosure', 'mandatory_disclosure_shortcode');

function syllabus_shortcode($atts){
    global $wpdb;
    $url = UPLOADS_URL;
    wp_enqueue_style('team-style', get_template_directory_uri().'/css/style.css');
    
    $cond = '';
    if($atts['department']!=''){
        $cond = " and department_id='$atts[department]'";
    }
    
    $output = '';
    $results = $wpdb->get_results($wpdb->prepare("SELECT * FROM syllabi WHERE deleted_at IS NULL $cond order by id asc"));
    if(!empty($results)){
        $output .= '<div class="row">
                        <div class="col-12">
                            <table class="table table-bordered">
                                <thead>
                                    <th>Title</th>
                                    <th>Attachment</th>
                                </thead>
                                <tbody>';
                                foreach($results as $result){
                                    $title = $result->title ?? '&nbsp;';
                                    $attachment = $result->attachment ?? '&nbsp;';
                                    $output .= '<tr>
                                                    <td>'.$title.'</td>
                                                    <td><a href="'.$url.$attachment.'" class="btn btn-success">View</a></td>
                                                </tr>';
                                }
        $output .=              '</tbody>
                            </table>
                        </div>
                    </div>';
    }
    
    wp_reset_postdata();
	return $output;
}

add_shortcode('syllabus', 'syllabus_shortcode');

function question_bank_shortcode($atts){
    global $wpdb;
    $url = UPLOADS_URL;
    wp_enqueue_style('team-style', get_template_directory_uri().'/css/style.css');
    
    $cond = '';
    if($atts['department']!=''){
        $cond = " and q.department_id='$atts[department]'";
    }
    
    $output = '';
    $results = $wpdb->get_results($wpdb->prepare("SELECT q.id,q.year,q.attachment,c.name as course,s.name as semester FROM question_papers as q left join courses as c on q.course_id=c.id left join semesters as s on q.semester_id=s.id WHERE q.deleted_at IS NULL $cond order by q.year desc, q.course_id asc, q.semester_id asc"));
    if(!empty($results)){
        $output .= '<div class="row">
                        <div class="col-12">
                            <table class="table table-bordered">
                                <thead>
                                    <th>Course</th>
                                    <th>Semester</th>
                                    <th>Year</th>
                                    <th>Attachment</th>
                                </thead>
                                <tbody>';
                                foreach($results as $result){
                                    $course = $result->course ?? '&nbsp;';
                                    $semester = $result->semester ?? '&nbsp;';
                                    $year = $result->year ?? '&nbsp;';
                                    $attachment = $result->attachment ?? '&nbsp;';
                                    $output .= '<tr>
                                                    <td>'.$course.'</td>
                                                    <td>'.$semester.'</td>
                                                    <td>'.$year.'</td>
                                                    <td><a href="'.$url.$attachment.'" class="btn btn-success" target="_blank">View</a></td>
                                                </tr>';
                                }
        $output .=              '</tbody>
                            </table>
                        </div>
                    </div>';
    }
    
    wp_reset_postdata();
	return $output;
}

add_shortcode('question_bank', 'question_bank_shortcode');

function achievement_slider_shortcode(){
    global $wpdb;
    $url = UPLOADS_URL;
    wp_enqueue_style( 'post-style', get_template_directory_uri().'/css/achieve.css' );
	wp_enqueue_script('post-script', get_template_directory_uri().'/js/achieve.js', array(), '1.0', true);
    
    $output = '';
    $results = $wpdb->get_results($wpdb->prepare("SELECT * FROM achievements WHERE deleted_at IS NULL ORDER BY id desc"));
	$output .= '<div class="achieve-slider">
                    <div class="achieve-header">
						<div class="achieve-title">Achievements</div>
						<div class="achieve-tools">
                            <div class="achieve-controls"><i class="fa-solid fa-square-caret-left" id="lacontrol1"></i><i class="fa-solid fa-square-caret-right" id="lacontrol2"></i></div>
                        </div>
					</div>
					<div class="achieve-body">
						<div class="achieve-container">
							<div class="achieve-content">';
								if($results){
									foreach($results as $result){
									    $name = $result->name ?? '';
										$image = $result->image ?? '';
										$output .= '<div class="achieve-item" title="'.$name.'"><img src="'.$url.$image.'" loading="lazy"></div>';
									}
								}
    $output .=              '</div>
						</div>
					</div>
				</div>';
    
    wp_reset_postdata();
	return $output;
}

add_shortcode('achievement_slider', 'achievement_slider_shortcode');

function handle_enquiry_form() {
    global $wpdb;

    // Get POST data
    $name = isset($_POST['name']) ? sanitize_text_field($_POST['name']) : '';
    $place = isset($_POST['place']) ? sanitize_text_field($_POST['place']) : '';
    $mobile = isset($_POST['mobile']) ? sanitize_text_field($_POST['mobile']) : '';
    $email = isset($_POST['email']) ? sanitize_email($_POST['email']) : '';
    $course_id = isset($_POST['course']) ? intval($_POST['course']) : 0;
    
    // Validation
    if (empty($name) || empty($mobile) || $course_id == 0) {
        wp_send_json_error(['message' => 'Please fill all required fields.']);
    }

    // Insert into database
    $data = [
        'name' => $name,
        'place' => $place,
        'mobile' => $mobile,
        'email' => $email,
        'course_id' => $course_id,
        'created_at' => current_time('mysql')
    ];
    $format = ['%s', '%s', '%s', '%s', '%d', '%s'];
    
    $inserted = $wpdb->insert('enquiries', $data, $format);

    if ($inserted) {
        wp_send_json_success(['message' => 'Enquiry Submitted Successfully!']);
    } else {
        wp_send_json_error(['message' => 'Error submitting enquiry. Try again.']);
    }

    wp_die();
}

// Hook for logged-in users
add_action('wp_ajax_handle_enquiry_form', 'handle_enquiry_form');

add_action('wp_ajax_nopriv_handle_enquiry_form', 'handle_enquiry_form');