<?php
/**
 * Template Name: Grievance Page
 *
 * Description: This is a custom template for displaying Grievance page.
 */
get_header();

global $wpdb;

$featured_image_url = esc_url(wp_upload_dir()['baseurl'].'/2025/05/casc.jpg');
if (has_post_thumbnail()) {
    $featured_image_id = get_post_thumbnail_id();
    $featured_image_url = wp_get_attachment_url($featured_image_id);
}

$departments = $wpdb->get_results($wpdb->prepare("SELECT * FROM departments WHERE deleted_at IS NULL ORDER BY name"));

if(isset($_POST['btn_submit'])){
    $data = [];
    $data['student'] = isset($_POST['student']) ? sanitize_text_field($_POST['student']) : null;
    $data['department_id'] = isset($_POST['department']) ? intval($_POST['department']) : 0;
    
    $allowed_ctype_values = ['UG Course', 'PG Course'];
    $data['ctype'] = isset($_POST['ctype']) ? sanitize_text_field($_POST['ctype']) : null;
    if (!in_array($data['ctype'], $allowed_ctype_values)) {
        $data['ctype'] = null;
    }
    
    $data['course_id'] = isset($_POST['course']) ? intval($_POST['course']) : 0;
    
    $allowed_semester_values = ['Semester 1', 'Semester 2', 'Semester 3', 'Semester 4', 'Semester 5', 'Semester 6'];
    $data['semester'] = isset($_POST['semester']) ? sanitize_text_field($_POST['semester']) : null;
    if (!in_array($data['semester'], $allowed_semester_values)) {    
        $data['semester'] = null;
    }
    
    $data['rollno'] = isset($_POST['rollno']) ? sanitize_textarea_field($_POST['rollno']) : null;
    $data['email'] = isset($_POST['email']) ? sanitize_textarea_field($_POST['email']) : null;
    $data['address'] = isset($_POST['address']) ? sanitize_textarea_field($_POST['address']) : null;
    $data['gtype'] = isset($_POST['gtype']) ? sanitize_textarea_field($_POST['gtype']) : null;
    $data['description'] = isset($_POST['description']) ? sanitize_textarea_field($_POST['description']) : null;
    
    $data['created_at'] = date('Y-m-d H:i:s');
    
    if($data['student'] != null && $data['department_id'] > 0 && $data['ctype'] != null && $data['course_id'] > 0 && $data['semester'] != null && $data['gtype'] > 0 != null && $data['description'] != null){
        $format = array('%s', '%d', '%s', '%d', '%s', '%s', '%s', '%s','%s', '%s', '%s');
        $inserted = $wpdb->insert('grievances', $data, $format);
        if($inserted){
            echo '<script>
                alert(\'Grievance Submitted Successfully !\');
                window.location.href = "' . esc_url(home_url('/student-support/evaluation/grievance-redressal-form/')) . '";
            </script>';
        } else {
            echo '<script>
                alert(\'Error submitting Grievance. Please try again.\');
            </script>';
        }
    } else {
        echo '<script>
            alert(\'Please fill in all required fields.\');
        </script>';
    }
} ?>
<link rel="stylesheet" href="<?php echo esc_url(get_template_directory_uri()); ?>/css/department.css?version=1.3" type="text/css">
<link rel="stylesheet" href="<?php echo esc_url(get_template_directory_uri()); ?>/css/custom-header.css" type="text/css">
<div class="custom-head" style="background-image: url('<?php echo esc_url($featured_image_url); ?>');">
    <div class="overlay"></div>
    <div class="custom-head-content">
        <span class="page-title">Teacher Evaluation</span>
    </div>
</div>
<div id="primary" class="content-area">
    <main id="main" class="site-main">
		<div class="dep-page form-pad">
            <div id="div-msg"></div>
            <div class="card card-primary feedback-form">
                <div class="card-body">
                    <form method="POST">
                        <div class="row">
                            <div class="col-12 col-sm-4">
                                <div class="form-group">
                                    <label class="required" for="student">Student Name</label>
                                    <input type="text" class="form-control" name="student" id="student" required>
                                </div>
                            </div>
                            <div class="col-12 col-sm-4">
                                <div class="form-group">
                                    <label class="required" for="department">Department</label>
                                    <select class="form-control cdata" name="department" id="department" required>
                                        <option value="">Select</option>
                                        <? foreach($departments as $department){ ?>
                                            <option value="<?=$department->id;?>"><?=$department->name;?></option>
                                        <? } ?>
                                    </select>
                                </div>
                            </div>
                            <div class="col-12 col-sm-4">
                                <div class="form-group">
                                    <label class="required" for="ctype">Course Type</label>
                                    <select class="form-control cdata" name="ctype" id="ctype" required>
                                        <option value="">Select</option>
                                        <option value="UG Course">UG</option>
                                        <option value="PG Course">PG</option>
                                    </select>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-12 col-sm-4">
                                <div class="form-group">
                                    <label class="required" for="course">Course</label>
                                    <select class="form-control" name="course" id="course" required>
                                        <option value="">Select</option>
                                    </select>
                                </div>
                            </div>
                            <div class="col-12 col-sm-2">
                                <div class="form-group">
                                    <label class="required" for="semester">Semester</label>
                                    <select class="form-control" name="semester" id="semester" required>
                                        <option value="">Select</option>
                                        <option value="Semester 1">Semester 1</option>
                                        <option value="Semester 2">Semester 2</option>
                                        <option value="Semester 3">Semester 3</option>
                                        <option value="Semester 4">Semester 4</option>
                                        <option value="Semester 5">Semester 5</option>
                                        <option value="Semester 6">Semester 6</option>
                                        <option value="Semester 7">Semester 7</option>
                                        <option value="Semester 8">Semester 8</option>
                                    </select>
                                </div>
                            </div>
                            <div class="col-12 col-sm-2">
                                <div class="form-group">
                                    <label for="rollno">Roll No</label>
                                    <input type="text" class="form-control" name="rollno" id="rollno">
                                </div>
                            </div>
                            <div class="col-12 col-sm-4">
                                <div class="form-group">
                                    <label for="email">Email</label>
                                    <input type="email" class="form-control" name="email" id="email">
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-12 col-sm-4">
                                <div class="form-group">
                                    <label for="address">Address</label>
                                    <textarea class="form-control" name="address" id="address" rows="4"></textarea>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-12">
                                <div class="form-group">
                                    <label>Type of Grievance</label>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-12">
                                <div class="form-group">
                                    <input type="radio" name="gtype" id="gtype-1" value="Teaching learning" required>
                                    <label for="gtype-1">Teaching learning</label>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-12">
                                <div class="form-group">
                                    <input type="radio" name="gtype" id="gtype-2" value="Examination (Internal/External)" required>
                                    <label for="gtype-2">Examination (Internal/External)</label>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-12">
                                <div class="form-group">
                                    <input type="radio" name="gtype" id="gtype-3" value="Ragging" required>
                                    <label for="gtype-3">Ragging</label>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-12">
                                <div class="form-group">
                                    <input type="radio" name="gtype" id="gtype-4" value="Sexual Harassment" required>
                                    <label for="gtype-4">Sexual Harassment</label>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-12">
                                <div class="form-group">
                                    <input type="radio" name="gtype" id="gtype-5" value="Any Others" required>
                                    <label for="gtype-5">Any Others</label>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-12">
                                <div class="form-group">
                                    <label for="description">Please specify your grievance in brief:</label>
                                    <textarea class="form-control" name="description" id="description" rows="10">Sir,</textarea>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-12">
                                <div class="form-group text-center">
                                    <button type="submit" name="btn_submit" class="btn btn-danger">Submit</button>
                                </div>
                            </div>
                        </div>
                    </form>
                </div>
            </div>
		</div>
    </main>
</div>
<script src="<?php echo esc_url(get_template_directory_uri()); ?>/js/feedback.js?version=1.1"></script>
<?php 
get_footer();