<?php
/**
 * Template Name: Library Evaluation Page
 *
 * Description: This is a custom template for displaying Library Evaluation page.
 */
get_header();

global $wpdb;

$featured_image_url = esc_url(wp_upload_dir()['baseurl'].'/2025/05/casc.jpg');
if (has_post_thumbnail()) {
    $featured_image_id = get_post_thumbnail_id();
    $featured_image_url = wp_get_attachment_url($featured_image_id);
}

if (!session_id()) {
    session_start();
}

if(isset($_POST['login'])){
    $username = isset($_POST['username']) ? sanitize_text_field($_POST['username']) : null;
    $password = isset($_POST['password']) ? sanitize_text_field($_POST['password']) : null;
    
    $logdata = $wpdb->get_row($wpdb->prepare("SELECT * FROM logins WHERE id = 2 and username = %s and password = %s", $username, $password));
    if (!empty($logdata)) {
        $_SESSION['authenticated2'] = true;
    } else {
        echo '<script>
            alert(\'Invalid Username or Password.\');
        </script>';
    }
}

$departments = $wpdb->get_results($wpdb->prepare("SELECT * FROM departments WHERE deleted_at IS NULL ORDER BY name"));
$questions = $wpdb->get_results($wpdb->prepare("SELECT * FROM library_questions ORDER BY id ASC"));

if(isset($_POST['btn_submit'])){
    $data = [];
    $data['student'] = isset($_POST['student']) ? sanitize_text_field($_POST['student']) : null;
    $data['department_id'] = isset($_POST['department']) ? intval($_POST['department']) : 0;
    
    $allowed_ctype_values = ['UG Course', 'PG Course'];
    $data['ctype'] = isset($_POST['ctype']) ? sanitize_text_field($_POST['ctype']) : null;
    if (!in_array($data['ctype'], $allowed_ctype_values)) {
        $data['ctype'] = null;
    }
    
    $data['course_id'] = isset($_POST['course']) ? intval($_POST['course']) : 0;
    
    $allowed_semester_values = ['Semester 1', 'Semester 2', 'Semester 3', 'Semester 4', 'Semester 5', 'Semester 6'];
    $data['semester'] = isset($_POST['semester']) ? sanitize_text_field($_POST['semester']) : null;
    if (!in_array($data['semester'], $allowed_semester_values)) {    
        $data['semester'] = null;
    }
    
    $data['year'] = isset($_POST['year']) ? intval($_POST['year']) : 0;
    $data['created_at'] = date('Y-m-d H:i:s');
    
    if($data['student'] != null && $data['department_id'] > 0 && $data['ctype'] != null && $data['course_id'] > 0 && $data['semester'] != null && $data['year'] > 0){
        $format = array('%s', '%d', '%s', '%d', '%s', '%d', '%s');
        $inserted = $wpdb->insert('library_feedback', $data, $format);
        if($inserted){
            $library_feedback_id = $wpdb->insert_id;
            $sdata = [];
            $sdata['library_feedback_id'] = $library_feedback_id;
            $sformat = array('%d', '%d', '%s', '%s');
            foreach($questions as $question){
                $question_id = $question->id;
                if(isset($_POST["qno-$question_id"])){
                    $answer = $_POST["qno-$question_id"];
                    if(is_array($answer)){
                        $answer = implode('@@',$answer);
                    }
                    
                    $sdata['question_id'] = $question_id;
                    $sdata['answer'] = $answer;
                    $sdata['created_at'] = date('Y-m-d H:i:s');
                    
                    $details_inserted = $wpdb->insert('library_feedback_items', $sdata, $sformat);
                }
            }
            unset($_SESSION['authenticated2']);
            echo '<script>
                alert(\'Feedback Submitted Successfully !\');
                window.location.href = "' . esc_url(home_url('/student-support/evaluation/library-evaluation/')) . '";
            </script>';  
        } else {
            echo '<script>
                alert(\'Error submitting feedback. Please try again.\');
            </script>';
        }
    } else {
        echo '<script>
            alert(\'Please fill in all required fields.\');
        </script>';
    }
} ?>
<link rel="stylesheet" href="<?php echo esc_url(get_template_directory_uri()); ?>/css/department.css?version=1.3" type="text/css">
<link rel="stylesheet" href="<?php echo esc_url(get_template_directory_uri()); ?>/css/custom-header.css" type="text/css">
<div class="custom-head" style="background-image: url('<?php echo esc_url($featured_image_url); ?>');">
    <div class="overlay"></div>
    <div class="custom-head-content">
        <span class="page-title">Library Evaluation</span>
    </div>
</div>
<div id="primary" class="content-area">
    <main id="main" class="site-main">
		<div class="dep-page form-pad">
            <div id="div-msg"></div>
            <div class="card card-primary feedback-form">
                <div class="card-body">
                    <? if (!isset($_SESSION['authenticated2']) || $_SESSION['authenticated2'] !== true) { ?>
                        <div class="row">
                            <div class="col-12 col-sm-4"></div>
                            <div class="col-12 col-sm-4">
                                <form method="POST">
                                    <p class="text-center"><b>Please Login to Continue...</b></p>
                                    <div class="form-group">
                                        <label for="username">Username</label>
                                        <input type="text" class="form-control" id="username" name="username" placeholder="Enter Username" autocomplete="off" required>
                                    </div>
                                    <div class="form-group">
                                        <label for="password">Password</label>
                                        <input type="password" class="form-control" id="password" name="password" placeholder="Password" autocomplete="off" required>
                                    </div>
                                    <button type="submit" class="btn btn-primary" name="login">Submit</button>
                                </form>
                            </div>
                        </div>
                        <? exit();
                    } ?>
                    <form method="POST">
                        <div class="row">
                            <div class="col-12 col-sm-4">
                                <div class="form-group">
                                    <label class="required" for="student">Student Name</label>
                                    <input type="text" class="form-control" name="student" id="student" required>
                                </div>
                            </div>
                            <div class="col-12 col-sm-4">
                                <div class="form-group">
                                    <label class="required" for="department">Department</label>
                                    <select class="form-control cdata" name="department" id="department" required>
                                        <option value="">Select</option>
                                        <? foreach($departments as $department){ ?>
                                            <option value="<?=$department->id;?>"><?=$department->name;?></option>
                                        <? } ?>
                                    </select>
                                </div>
                            </div>
                            <div class="col-12 col-sm-4">
                                <div class="form-group">
                                    <label class="required" for="ctype">Course Type</label>
                                    <select class="form-control cdata" name="ctype" id="ctype" required>
                                        <option value="">Select</option>
                                        <option value="UG Course">UG</option>
                                        <option value="PG Course">PG</option>
                                    </select>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-12 col-sm-4">
                                <div class="form-group">
                                    <label class="required" for="course">Course</label>
                                    <select class="form-control" name="course" id="course" required>
                                        <option value="">Select</option>
                                    </select>
                                </div>
                            </div>
                            <div class="col-12 col-sm-4">
                                <div class="form-group">
                                    <label class="required" for="semester">Semester</label>
                                    <select class="form-control" name="semester" id="semester" required>
                                        <option value="">Select</option>
                                        <option value="Semester 1">Semester 1</option>
                                        <option value="Semester 2">Semester 2</option>
                                        <option value="Semester 3">Semester 3</option>
                                        <option value="Semester 4">Semester 4</option>
                                        <option value="Semester 5">Semester 5</option>
                                        <option value="Semester 6">Semester 6</option>
                                        <option value="Semester 7">Semester 7</option>
                                        <option value="Semester 8">Semester 8</option>
                                    </select>
                                </div>
                            </div>
                            <div class="col-12 col-sm-4">
                                <div class="form-group">
                                    <label class="required" for="year">Year</label>
                                    <select class="form-control" name="year" id="year" required>
                                        <? for($i=date('Y'); $i >= 2022; $i--){ ?>
                                            <option value="<?=$i;?>"><?=$i.' - '.($i+1);?></option>
                                        <? } ?>
                                    </select>
                                </div>
                            </div>
                        </div>
                        <div style="width: 95%; margin-left: 20px;">
                            <div class="row">
                                <div class="col-12">
                                    <div class="form-group">
                                        1. Do you have the habit of visiting the Library ?
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-1" id="qno-1-1" value="Yes" required>
                                        <label for="qno-1-1">Yes</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-1" id="qno-1-2" value="No" required>
                                        <label for="qno-1-2">No</label>
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12">
                                    <div class="form-group">
                                        2. How frequently do you visit the library ?
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-2" id="qno-2-1" value="Daily">
                                        <label for="qno-2-1">Daily</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-2" id="qno-2-2" value="Occasionally">
                                        <label for="qno-2-2">Occasionally</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-2" id="qno-2-3" value="Never">
                                        <label for="qno-2-3">Never</label>
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12">
                                    <div class="form-group">
                                        3. Purpose of your Library visit
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="checkbox" name="qno-3[]" id="qno-3-1" value="Reading newspapers">
                                        <label for="qno-3-1">Reading newspapers</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="checkbox" name="qno-3[]" id="qno-3-2" value="Borrow & return books">
                                        <label for="qno-3-2">Borrow & return books</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-3">
                                    <div class="form-group">
                                        <input type="checkbox" name="qno-3[]" id="qno-3-3" value="Preparing class notes, assignments">
                                        <label for="qno-3-3">Preparing class notes, assignments</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="checkbox" name="qno-3[]" id="qno-3-4" value="General reading">
                                        <label for="qno-3-4">General reading</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-3">
                                    <div class="form-group">
                                        <input type="checkbox" name="qno-3[]" id="qno-3-5" value="Consulting reference books">
                                        <label for="qno-3-5">Consulting reference books</label>
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12">
                                    <div class="form-group">
                                        4. What type of books do you most often borrow from the Library ?
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="checkbox" name="qno-4[]" id="qno-4-1" value="General">
                                        <label for="qno-4-1">General</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="checkbox" name="qno-4[]" id="qno-4-2" value="Subject books">
                                        <label for="qno-4-2">Subject books</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="checkbox" name="qno-4[]" id="qno-4-3" value="Fiction">
                                        <label for="qno-4-3">Fiction</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="checkbox" name="qno-4[]" id="qno-4-4" value="Poetry">
                                        <label for="qno-4-4">Poetry</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="checkbox" name="qno-4[]" id="qno-4-5" value="Novel">
                                        <label for="qno-4-5">Novel</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="checkbox" name="qno-4[]" id="qno-4-6" value="Story">
                                        <label for="qno-4-6">Story</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="checkbox" name="qno-4[]" id="qno-4-7" value="Essay">
                                        <label for="qno-4-7">Essay</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="checkbox" name="qno-4[]" id="qno-4-8" value="Biography">
                                        <label for="qno-4-8">Biography</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="checkbox" name="qno-4[]" id="qno-4-9" value="Spiritual">
                                        <label for="qno-4-9">Spiritual</label>
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12">
                                    <div class="form-group">
                                        5. What type of books do you prefer for reading ?
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="checkbox" name="qno-5[]" id="qno-5-1" value="General">
                                        <label for="qno-5-1">General</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="checkbox" name="qno-5[]" id="qno-5-2" value="Subject books">
                                        <label for="qno-5-2">Subject books</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="checkbox" name="qno-5[]" id="qno-5-3" value="Fiction">
                                        <label for="qno-5-3">Fiction</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="checkbox" name="qno-5[]" id="qno-5-4" value="Poetry">
                                        <label for="qno-5-4">Poetry</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="checkbox" name="qno-5[]" id="qno-5-5" value="Novel">
                                        <label for="qno-5-5">Novel</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="checkbox" name="qno-5[]" id="qno-5-6" value="Story">
                                        <label for="qno-5-6">Story</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="checkbox" name="qno-5[]" id="qno-5-7" value="Essay">
                                        <label for="qno-5-7">Essay</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="checkbox" name="qno-5[]" id="qno-5-8" value="Biography">
                                        <label for="qno-5-8">Biography</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="checkbox" name="qno-5[]" id="qno-5-9" value="Spiritual">
                                        <label for="qno-5-9">Spiritual</label>
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12">
                                    <div class="form-group">
                                        6. What type of magazines do you prefer to read ?
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-6" id="qno-6-1" value="Popular magazines" required>
                                        <label for="qno-6-1">Popular magazines</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-6" id="qno-6-2" value="Career magazines" required>
                                        <label for="qno-6-2">Career magazines</label>
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12">
                                    <div class="form-group">
                                        7. Are you satisfied with the reference collections in your Library ?
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-7" id="qno-7-1" value="Yes" required>
                                        <label for="qno-7-1">Yes</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-7" id="qno-7-2" value="No" required>
                                        <label for="qno-7-2">No</label>
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12">
                                    <div class="form-group">
                                        8. How do you find documents of interest in your Library ?
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12 col-sm-3">
                                    <div class="form-group">
                                        <input type="radio" name="qno-8" id="qno-8-1" value="Consulting with library staff" required>
                                        <label for="qno-8-1">Consulting with library staff</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-3">
                                    <div class="form-group">
                                        <input type="radio" name="qno-8" id="qno-8-2" value="Direct from shelf" required>
                                        <label for="qno-8-2">Direct from shelf</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-3">
                                    <div class="form-group">
                                        <input type="radio" name="qno-8" id="qno-8-3" value="With the help of friends" required>
                                        <label for="qno-8-3">With the help of friends</label>
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12">
                                    <div class="form-group">
                                        9. Is the Library Orientation programme helpful for you ?
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-9" id="qno-9-1" value="Yes" required>
                                        <label for="qno-9-1">Yes</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-9" id="qno-9-2" value="No" required>
                                        <label for="qno-9-2">No</label>
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12">
                                    <div class="form-group">
                                        10. Do you know the classification scheme used in your Library ?
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-10" id="qno-10-1" value="Yes" required>
                                        <label for="qno-10-1">Yes</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-10" id="qno-10-2" value="No" required>
                                        <label for="qno-10-2">No</label>
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12">
                                    <div class="form-group">
                                        11. Are you satisfied with the working hours of the Library ?
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-11" id="qno-11-1" value="Satisfied" required>
                                        <label for="qno-11-1">Satisfied</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-11" id="qno-11-2" value="Dissatisfied" required>
                                        <label for="qno-11-2">Dissatisfied</label>
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12">
                                    <div class="form-group">
                                        12. Do you find any difficulty while using the Library ? (write if any)
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12">
                                    <div class="form-group">
                                        <textarea class="form-control" name="qno-12" id="qno-12" rows="4"></textarea>
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12">
                                    <div class="form-group">
                                        13. Do you use internet in your Library ?
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-13" id="qno-13-1" value="Yes" required>
                                        <label for="qno-13-1">Yes</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-13" id="qno-13-2" value="No" required>
                                        <label for="qno-13-2">No</label>
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12">
                                    <div class="form-group">
                                        14. Availability of Library during Library hours ?
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-14" id="qno-14-1" value="Mostly Always" required>
                                        <label for="qno-14-1">Mostly Always</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-14" id="qno-14-2" value="Rarely" required>
                                        <label for="qno-14-2">Rarely</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-14" id="qno-14-3" value="Not at all" required>
                                        <label for="qno-14-3">Not at all</label>
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12">
                                    <div class="form-group">
                                        15. How would you rate the quality of services offered by the Library ?
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-15" id="qno-15-1" value="Excellent" required>
                                        <label for="qno-15-1">Excellent</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-15" id="qno-15-2" value="Good" required>
                                        <label for="qno-15-2">Good</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-15" id="qno-15-3" value="Poor" required>
                                        <label for="qno-15-3">Poor</label>
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12">
                                    <div class="form-group">
                                        16. How satisfied are you with the following services offered by the Library ?
                                    </div>
                                </div>
                            </div>
                            <div style="width: 100%; margin-left: 20px;">
                                <div class="col-12">
                                    <div class="form-group">
                                        A. Computer with internet
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-12 col-sm-2">
                                        <div class="form-group">
                                            <input type="radio" name="qno-17" id="qno-17-1" value="Excellent" required>
                                            <label for="qno-17-1">Excellent</label>
                                        </div>
                                    </div>
                                    <div class="col-12 col-sm-2">
                                        <div class="form-group">
                                            <input type="radio" name="qno-17" id="qno-17-2" value="Good" required>
                                            <label for="qno-17-2">Good</label>
                                        </div>
                                    </div>
                                    <div class="col-12 col-sm-2">
                                        <div class="form-group">
                                            <input type="radio" name="qno-17" id="qno-17-3" value="Poor" required>
                                            <label for="qno-17-3">Poor</label>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-12">
                                    <div class="form-group">
                                        B. Photostat
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-12 col-sm-2">
                                        <div class="form-group">
                                            <input type="radio" name="qno-18" id="qno-18-1" value="Excellent" required>
                                            <label for="qno-18-1">Excellent</label>
                                        </div>
                                    </div>
                                    <div class="col-12 col-sm-2">
                                        <div class="form-group">
                                            <input type="radio" name="qno-18" id="qno-18-2" value="Good" required>
                                            <label for="qno-18-2">Good</label>
                                        </div>
                                    </div>
                                    <div class="col-12 col-sm-2">
                                        <div class="form-group">
                                            <input type="radio" name="qno-18" id="qno-18-3" value="Poor" required>
                                            <label for="qno-18-3">Poor</label>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-12">
                                    <div class="form-group">
                                        C. References
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-12 col-sm-2">
                                        <div class="form-group">
                                            <input type="radio" name="qno-19" id="qno-19-1" value="Excellent" required>
                                            <label for="qno-19-1">Excellent</label>
                                        </div>
                                    </div>
                                    <div class="col-12 col-sm-2">
                                        <div class="form-group">
                                            <input type="radio" name="qno-19" id="qno-19-2" value="Good" required>
                                            <label for="qno-19-2">Good</label>
                                        </div>
                                    </div>
                                    <div class="col-12 col-sm-2">
                                        <div class="form-group">
                                            <input type="radio" name="qno-19" id="qno-19-3" value="Poor" required>
                                            <label for="qno-19-3">Poor</label>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-12">
                                    <div class="form-group">
                                        D. Cleanliness
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-12 col-sm-2">
                                        <div class="form-group">
                                            <input type="radio" name="qno-20" id="qno-20-1" value="Excellent" required>
                                            <label for="qno-20-1">Excellent</label>
                                        </div>
                                    </div>
                                    <div class="col-12 col-sm-2">
                                        <div class="form-group">
                                            <input type="radio" name="qno-20" id="qno-20-2" value="Good" required>
                                            <label for="qno-20-2">Good</label>
                                        </div>
                                    </div>
                                    <div class="col-12 col-sm-2">
                                        <div class="form-group">
                                            <input type="radio" name="qno-20" id="qno-20-3" value="Poor" required>
                                            <label for="qno-20-3">Poor</label>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12">
                                    <div class="form-group">
                                        17. How accessible is the staff of the library ?
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-21" id="qno-21-1" value="Mostly Always" required>
                                        <label for="qno-21-1">Mostly Always</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-21" id="qno-21-2" value="Rarely" required>
                                        <label for="qno-21-2">Rarely</label>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-2">
                                    <div class="form-group">
                                        <input type="radio" name="qno-21" id="qno-21-3" value="Not at all" required>
                                        <label for="qno-21-3">Not at all</label>
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12">
                                    <div class="form-group">
                                        18. Suggestions to improve the College Library services ?
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12">
                                    <div class="form-group">
                                        <textarea class="form-control" name="qno-22" id="qno-22" rows="4"></textarea>
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12">
                                    <div class="form-group">
                                        19. Do you have specific suggestions for subject-related books that you would like to see added to the Library ? Write the details of the titles and authors.
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-12">
                                    <div class="form-group">
                                        <textarea class="form-control" name="qno-23" id="qno-23" rows="4"></textarea>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-12">
                                <div class="form-group text-center">
                                    <button type="submit" name="btn_submit" class="btn btn-danger">Submit</button>
                                </div>
                            </div>
                        </div>
                    </form>
                </div>
            </div>
		</div>
    </main>
</div>
<script src="<?php echo esc_url(get_template_directory_uri()); ?>/js/feedback.js?version=1.1"></script>
<?php 
get_footer();